==> ejc-bfyjerp-api-3.0.0-20241108.073345-21-sources.jar: com/ejianc/business/bid/vo/CALockDetailVO.java <==
package com.ejianc.business.bid.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 投标管理-CA锁登记子表
 * 
 * @author generator
 * 
 */
public class CALockDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表ID
    private String lockType; // 锁类型：1-企业锁，2法人锁，3-授权人锁，4-造价师锁
    private String acc; // 账号
    private String pwd; // 密码
    private Date handleTime; // 办理时间
    private Date endTime; // 到期时间
    private String keerper; // 保管人
    private String salt; // 盐
    private String memo; // 备注
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getLockType() {
        return lockType;
    }

    public void setLockType(String lockType) {
        this.lockType = lockType;
    }
    public String getAcc() {
        return acc;
    }

    public void setAcc(String acc) {
        this.acc = acc;
    }
    public String getPwd() {
        return pwd;
    }

    public void setPwd(String pwd) {
        this.pwd = pwd;
    }
    public Date getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(Date handleTime) {
        this.handleTime = handleTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public String getKeerper() {
        return keerper;
    }

    public void setKeerper(String keerper) {
        this.keerper = keerper;
    }
    public String getSalt() {
        return salt;
    }

    public void setSalt(String salt) {
        this.salt = salt;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20241121.071814-57-sources.jar: com/ejianc/business/bid/vo/CALockDetailVO.java <==
package com.ejianc.business.bid.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 投标管理-CA锁登记子表
 * 
 * @author generator
 * 
 */
public class CALockDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表ID
    private String lockType; // 锁类型：1-企业锁，2-法人锁，3-授权人锁，4-造价师锁
    private String acc; // 账号
    private String pwd; // 密码
    private Date handleTime; // 办理时间
    private Date endTime; // 到期时间
    private String keerper; // 保管人
    private String salt; // 盐
    private String memo; // 备注


    /** 台账使用字段 **/
    private String belongWebAddr; // 所属区域网址
    private String belongArea; // CA锁所属区域

    public String getBelongWebAddr() {
        return belongWebAddr;
    }

    public void setBelongWebAddr(String belongWebAddr) {
        this.belongWebAddr = belongWebAddr;
    }

    public String getBelongArea() {
        return belongArea;
    }

    public void setBelongArea(String belongArea) {
        this.belongArea = belongArea;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getLockType() {
        return lockType;
    }

    public void setLockType(String lockType) {
        this.lockType = lockType;
    }
    public String getAcc() {
        return acc;
    }

    public void setAcc(String acc) {
        this.acc = acc;
    }
    public String getPwd() {
        return pwd;
    }

    public void setPwd(String pwd) {
        this.pwd = pwd;
    }
    public Date getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(Date handleTime) {
        this.handleTime = handleTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public String getKeerper() {
        return keerper;
    }

    public void setKeerper(String keerper) {
        this.keerper = keerper;
    }
    public String getSalt() {
        return salt;
    }

    public void setSalt(String salt) {
        this.salt = salt;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
